@@ -4,6 +4,22 @@ from datetime import datetime
 import requests
 from os import path
 
+
+def json_parameters_function():
+    def inner(func):
+        def wrapper(message):
+            o = JsonObject.load(message.body)
+            p = {}
+            for v in func.__code__.co_varnames:
+                if v in o.__dict__:
+                    p[v] = o.__dict__[v]
+                else:
+                    p[v] = None
+            func(**p)
+        return wrapper
+    return inner
+
+
 class classorinstancemethod(classmethod):
 
     def __get__(self, instance, type_):
